@@ -7,7 +7,7 @@ package App::TestOnTap::Args;
 use strict;
 use warnings;
 
-use App::TestOnTap::Util qw(slashify $IS_WINDOWS);
+use App::TestOnTap::Util qw(slashify $IS_WINDOWS $IS_PACKED);
 use App::TestOnTap::ExecMap;
 use App::TestOnTap::Config;
 use App::TestOnTap::WorkDirManager;
@@ -15,10 +15,12 @@ use App::TestOnTap::WorkDirManager;
 use FindBin qw($RealBin $Script);
 use Getopt::Long qw(GetOptionsFromArray :config require_order no_ignore_case bundling);
 use Pod::Usage;
+use Pod::Simple::Search;
 use Grep::Query;
 use File::Basename;
 use File::Spec;
 use File::Path;
+use POSIX;
 use UUID::Tiny qw(:std);
 
 # CTOR
@@ -56,15 +58,18 @@ sub __parseArgv
 			archive => 0,				# don't save results as archive
 			v => 0,						# don't let through output from tests
 			
-			# undoc
+			# hidden
 			#
-			_pp => undef				# make a binary using pp
+			_help => 0,
+			_pp => 0,					# make a binary using pp
+			'_pp-output' => undef,		# binary name
+			'_pp-force' => 0,			# overwrite existing file
 		);
 		
 	my @specs =
 		(
 			'usage|?',
-			'help',
+			'help|h',
 			'manual',
 			'version',
 			'execmap=s',
@@ -77,13 +82,20 @@ sub __parseArgv
 			'archive!',
 			'v|verbose+',
 			
-			# undoc
+			# hidden
 			#
-			'_pp:s',
+			'_help',
+			'_pp',
+			'_pp-output=s',
+			'_pp-force!',
 		);
 
-	my $argsPodInput = $self->__findPod('App/TestOnTap/Args.pod');
-	my $manualPodInput = $self->__findPod('App/TestOnTap.pod');
+	my $_argsPodName = 'App/TestOnTap/_Args.pod';
+	my $_argsPodInput = Pod::Simple::Search->find($_argsPodName);
+	my $argsPodName = 'App/TestOnTap/Args.pod';
+	my $argsPodInput = Pod::Simple::Search->find($argsPodName);
+	my $manualPodName = 'App/TestOnTap.pod';
+	my $manualPodInput = Pod::Simple::Search->find($manualPodName);
 	
 	# for consistent error handling below, trap getopts problems
 	# 
@@ -101,9 +113,21 @@ sub __parseArgv
 	#
 	$self->{$_} = $rawOpts{$_} foreach (qw(v archive defines timer));
 
+	# help with the hidden flags...
+	#
+	pod2usage(-input => $_argsPodInput, -exitval => 0, -verbose => 2, -noperldoc => 1) if $rawOpts{_help};
+
 	# for the special selection of running pp, do this first, and it will not return
 	#
-	$self->__createBinary($rawOpts{_pp}, $rawOpts{v}, $version, $argsPodInput, $manualPodInput) if (defined($rawOpts{_pp}));
+	$self->__createBinary
+				(
+					$rawOpts{'_pp-output'},
+					$rawOpts{'_pp-force'},
+					$rawOpts{v},
+					$version,
+					$argsPodName, $argsPodInput,
+					$manualPodName, $manualPodInput
+				) if ($rawOpts{_pp});
 
 	# if any of the doc switches made, display the pod
 	#
@@ -299,28 +323,48 @@ sub include
 sub __createBinary
 {
 	my $self = shift;
-	my $bin = shift;
+	my $output = shift || '.';
+	my $force = shift;
 	my $verbosity = shift;
 	my $version = shift;
+	my $argsPodName = shift;
 	my $argsPodInput = shift;
+	my $manualPodName = shift;
 	my $manualPodInput = shift;
 	
+	die("Sorry, you're already running a binary/packed instance\n") if $IS_PACKED;
+	
 	eval "require PAR::Packer";
 	die("Sorry, it appears PAR::Packer is not installed\n  $@\n") if $@;
-	
+
+	my $os = $IS_WINDOWS ? 'windows' : $^O;
+	my $arch = (POSIX::uname())[4]; 
 	my $exeSuffix = $IS_WINDOWS ? '.exe' : '';
-	$bin = slashify(File::Spec->rel2abs($bin ? $bin : "$Script-$version$exeSuffix"));
+	if (-d $output)
+	{
+		$output = slashify(File::Spec->rel2abs("$output/$Script-$version-$os-$arch$exeSuffix"));
+	}
+	else
+	{
+		$output = slashify(File::Spec->rel2abs($output));
+	}
 	
-	die("The path '$bin' already exists\n") if -e $bin;
-	
-	my $argsPodOutput = slashify($argsPodInput, '/');
-	$argsPodOutput =~ s#.*/lib/(.+)#lib/$1#;
-	
-	my $manualPodOutput = slashify($manualPodInput, '/');
-	$manualPodOutput =~ s#.*/lib/(.+)#lib/$1#;
-	
-	my @vs = $verbosity ? ('-', 'v' x $verbosity) : ();
-	my @cmd = ('pp', @vs, '-a', "$argsPodInput;$argsPodOutput", '-a', "$manualPodInput;$manualPodOutput", '-o', $bin, slashify("$RealBin/$Script"));
+	die("The path '$output' already exists\n") if (!$force && -e $output);
+	unlink($output);
+	die("Attempt to forcible remove '$output' failed: $!\n") if -e $output;
+		
+	my @vs = $verbosity > 1 ? ('-' . 'v' x ($verbosity - 1)) : ();
+	my @liblocs = map { $_ ne '.' ? ('-I', slashify(File::Spec->rel2abs($_))) : () } @INC;
+	my @cmd =
+		(
+			'pp',
+			@vs,
+			@liblocs,
+			'-a', "$argsPodInput;lib/$argsPodName",
+			'-a', "$manualPodInput;lib/$manualPodName",
+			'-o', $output,
+			slashify("$RealBin/$Script")
+		);
 
 	if ($verbosity)
 	{
@@ -329,32 +373,11 @@ sub __createBinary
 	}
 	
 	my $xit = system(@cmd) >> 8;
-	die("Problems creating binary '$bin': '$xit'") if ($xit || !-f $bin);
+	die("Problems creating binary '$output': '$xit'") if ($xit || !-f $output);
 	
-	print "Created '$bin'!\n";
+	print "Created '$output'!\n";
 	
 	exit(0);
 }
 
-sub __findPod
-{
-	my $self = shift;
-	my $pod = shift;
-
-	my $input;	
-	foreach my $inc (@INC)
-	{
-		my $loc = "$inc/$pod";
-		if (-e $loc)
-		{
-			$input = slashify(File::Spec->rel2abs($loc));
-			last;
-		}
-	}
-	
-	die("Pod not found: '$pod'\n") unless $input;
-	
-	return $input;
-}
-
 1;
